@@ -6,7 +6,7 @@ import numpy as np
 from ggplot.components import smoothers
 
 class stat_smooth(geom):
-    VALID_AES = ['x', 'y', 'color', 'alpha', 'label', 'se', 'method', 'span']
+    VALID_AES = ['x', 'y', 'color', 'alpha', 'label', 'se', 'linestyle', 'method', 'span']
 
     def plot_layer(self, layer):
         layer = {k: v for k, v in layer.iteritems() if k in self.VALID_AES}
